       IDENTIFICATION DIVISION.
       PROGRAM-ID.    NUMBERC1.
       AUTHOR.        SIMOTIME TECHNOLOGIES.
      *****************************************************************
      * Copyright (C) 1987-2019 SimoTime Technologies.                *
      *                                                               *
      * All rights reserved.  Unpublished, all rights reserved under  *
      * copyright law and international treaty.  Use of a copyright   *
      * notice is precautionary only and does not imply publication   *
      * or disclosure.                                                *
      *                                                               *
      * Permission to use, copy, modify and distribute this software  *
      * for any  purpose requires a fee to be paid to SimoTime        *
      * Technologies. Once the fee is received by SimoTime the latest *
      * version of the software will be delivered and a license will  *
      * be granted for use within an enterprise, provided the         *
      * SimoTime copyright notice appear on all copies of the         *
      * software. The SimoTime name or Logo may not be used in any    *
      * advertising or publicity pertaining to the use of the         *
      * software without the written permission of SimoTime           *
      * Technologies.                                                 *
      *                                                               *
      * SimoTime Technologies makes no warranty or representations    *
      * about the suitability of the software for any purpose. It is  *
      * provided "AS IS" without any expressed or implied warranty,   *
      * including the implied warranties of merchantability, fitness  *
      * for a particular purpose and non-infringement. SimoTime       *
      * Technologies shall not be liable for any direct, indirect,    *
      * special or consequential damages resulting from the loss of   *
      * use, data or projects, whether in an action of contract or    *
      * tort, arising out of or in connection with the use or         *
      * performance of this software                                  *
      *                                                               *
      * SimoTime Technologies                                         *
      * 15 Carnoustie Drive                                           *
      * Novato, CA 94949-5849                                         *
      * 415.883.6565                                                  *
      *                                                               *
      * RESTRICTED RIGHTS LEGEND                                      *
      * Use, duplication, or disclosure by the Government is subject  *
      * to restrictions as set forth in subparagraph (c)(1)(ii) of    *
      * the Rights in Technical Data and Computer Software clause at  *
      * DFARS 52.227-7013 or subparagraphs (c)(1) and (2) of          *
      * Commercial  Computer Software - Restricted Rights  at 48      *
      * CFR 52.227-19, as applicable.  Contact SimoTime Technologies, *
      * 15 Carnoustie Drive, Novato, CA 94949-5849.                   *
      *                                                               *
      *****************************************************************
      *      This program is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *****************************************************************
      * Source Member: NUMBERC1.CBL
      *****************************************************************
      *
      * NUMBERC1 - Numeric formats for COBOL.
      *
      * DESCRIPTION
      * -----------
      * This set of programs is used to show the various numeric
      * format used by the COBOL Program Language.
      *
      * This program illustrates the use of some of the commonly
      * used numeric formats. It will show actual hex-dump content of
      * the fields along with the field length for the display format
      * (actual digits), the packed format (COMP-3) and the binary
      * (COMP)
      * formats.
      *
      * The COBOL programs are compiled with the ASSIGN(EXTERNAL)
      * directive. This provides for external file mapping of file
      * names.
      *
      * When running with Net Express the IBMCOMP an NOTRUNC directives
      * will be required to maintain compatability with the mainframe
      * format and field sizes for binary fields.
      *
      * This technique provides for the use of a single COBOL source
      * program that will run on OS/390, Windows or Unix.
      *
      * This program will run on a Personal Computer with Windows
      * and Micro Focus Net Express or Mainframe Express.
      *
      * This program will also run on an IBM Mainframe.
      *
      *****************************************************************
      *
      * MAINTENANCE
      * -----------
      * 1996/03/15 Simmons, Created program.
      * 1996/03/15 Simmons, No changes to date.
      *
      *****************************************************************
      *
       ENVIRONMENT DIVISION.
       DATA DIVISION.
       WORKING-STORAGE SECTION.
      *****************************************************************
      *    Data-structure for Title and Copyright...
      *    ------------------------------------------------------------
       01  SIM-TITLE.
           05  T1 pic X(11) value '* NUMBERC1 '.
           05  T2 pic X(34) value 'Self Study, Numeric Formats COBOL '.
           05  T3 pic X(10) value ' v06.03.31'.
           05  T4 pic X(24) value ' http://www.simotime.com'.
       01  SIM-COPYRIGHT.
           05  C1 pic X(11) value '* NUMBERC1 '.
           05  C2 pic X(20) value 'Copyright 1987-2019 '.
           05  C3 pic X(28) value '   SimoTime Technologies    '.
           05  C4 pic X(20) value ' All Rights Reserved'.

       01  SIM-THANKS-01.
           05  C1 pic X(11) value '* NUMBERC1 '.
           05  C2 pic X(32) value 'Thank you for using this program'.
           05  C3 pic X(32) value ' provided from SimoTime Technolo'.
           05  C4 pic X(04) value 'gies'.

       01  SIM-THANKS-02.
           05  C1 pic X(11) value '* NUMBERC1 '.
           05  C2 pic X(32) value 'Please send all inquires or sugg'.
           05  C3 pic X(32) value 'estions to the helpdesk@simotime'.
           05  C4 pic X(04) value '.com'.
      *****************************************************************
      *    Buffer used for posting messages to the console.
      *    ------------------------------------------------------------
       01  MESSAGE-BUFFER.
           05  MESSAGE-HEADER      pic X(11)   value '* NUMBERC1 '.
           05  MESSAGE-TEXT        pic X(68).

      *****************************************************************
      *    Coding techniques for various numeric formats...
      *    ------------------------------------------------------------
      *    The following shows the full syntax for ZONED-DECIMAL
      *
       01  ZONE-DECIMAL-UNSIGN     pic 9(5)  USAGE IS DISPLAY.
      *
      *    The preceding is normally coded as follows. Since there is
      *    no USAGE clause the default is DISPLAY or ZONED-DECIMAL.
      *
       01  ZONE-DECIMAL-UNSIGN-N   PIC 9(5).
      *
      *    For Working Storage fields a value clause may be added to
      *    minimize or avoid the occurence of a "S0C7" or an error
      *    message of "Invalid value in numeric field" followed
      *    by a program ABEND. The value clause will cause the field
      *    to contain all ZEROES when the program is loaded. If the
      *    value clause is not used as follows the numeric field may
      *    contain spaces.
      *
       01  ZONE-DECIMAL-UNSIGN-NV  PIC 9(5) VALUE 0.

      *    ------------------------------------------------------------
      *    The following is the full syntax for PACKED-DECIMAL.
      *
       01  PACK-DECIMAL-UNSIGN     pic 9(5)  USAGE IS COMPUTATIONAL-3.
      *
      *    The preceding is normally coded as follows.
      *    For the USAGE clause the syntax may be abbreviated. The
      *    "USAGE IS" part of the clause is not neccessary and the
      *    COMPUTATIONAL-3 may be abbreviated as COMP-3.
      *    The VALUE clause is optional and will initialize the
      *    field to ZEROES when the program is started.
      *
       01  PACK-DECIMAL-UNSIGN-N   pic 9(5)  COMP-3 VALUE 0.

      *    ------------------------------------------------------------
      *    The following is the full syntax for BINARY or COMP field.
       01  BINARY-UNSIGN           pic 9(5)  USAGE IS COMPUTATIONAL.
      *
      *    The preceding is normally coded as follows.
      *    The VALUE clause is optional and will initialize the
      *    field to ZEROES when the program is started.
      *
       01  BINARY-UNSIGN-2         pic 9(5)  COMP VALUE 0.

      *****************************************************************
      *    Various numeric formats used by COBOL...
      *    ------------------------------------------------------------
       01  TEXT-ZONED-DECIMAL.
           05  NUMB-ZONED-DECIMAL pic 9(5)  value 123.
       01  TEXT-ZONED-DECIMAL-SIGN.
           05  SIGN-ZONED-DECIMAL pic S9(5) value 123.

       01  TEXT-PACKED-DECIMAL.
           05  NUMB-PACKED-DECIMAL pic 9(5)  COMP-3 value 123.
       01  TEXT-PACKED-DECIMAL-SIGN.
           05  SIGN-PACKED-DECIMAL pic S9(5) COMP-3 value 123.

       01  TEXT-BINARY.
           05  NUMB-BINARY         pic 9(5)  COMP   value 123.
       01  TEXT-BINARY-SIGN.
           05  SIGN-BINARY         pic S9(5) COMP   value 123.

       01  PACK-DECIMAL-S3V2-TEXT.
           05  PACK-DECIMAL-S3V2   pic S9(3)V99 COMP-3 value 6.15.
       01  SLS-S3V2-TEXT.
           05  SLS-S3V2-NUMB       pic S9(3)V99 SIGN LEADING SEPARATE
                                   value 0.

       01  TEXT-SIGN-LEAD-SEPARATE.
           05  SIGN-LEAD-SEPARATE  pic S9(5) SIGN LEADING SEPARATE
                                   value 0.

       01  PRINT-LINE.
           05  FILLER              pic X(8) value 'Edited: '.
           05  PRINT-NUMBER        pic +ZZZ.99.

       01  W-SIGN-06.
           05  W-SIGN              pic X       value SPACE.
           05  W-SIGN-VALUE        pic X(3)    value SPACES.
           05  W-SIGN-POINT        pic X       value '.'.
           05  W-SIGN-DECIMAL      pic X(2)    value SPACES.

       01  FIELD-LENGTH            pic 9(3)    value 0.
       01  FIELD-LENGTH-X          REDEFINES   FIELD-LENGTH
                                   pic X(3).
       COPY PASSDUMP.

      *****************************************************************
       PROCEDURE DIVISION.
           perform FIRST-TIME-LOGIC

      *    ------------------------------------------------------------
      *    Example-01, Show the Hex format for an unsigned, positive
      *    and negative Zoned-Decimal field or USAGE IS DISPLAY...
           perform ZONED-FIELD

      *    ------------------------------------------------------------
      *    Example-02, Show the Hex format for an unsigned, positive
      *    and negative Packed-Decimal field or USAGE IS COMP-3...
           perform PACKED-FIELD

      *    ------------------------------------------------------------
      *    Example-03, Show the Hex format for an unsigned, positive
      *    and negative Binary field or USAGE IS COMP...
           perform BINARY-FIELD

      *    ------------------------------------------------------------
      *    Example-04, Show how to convert a packed-decimal number to a
      *    display number with a separate leading sign character.
      *    Convert from... PIC S9(5) USAGE IS COMPUTATIONAL-3
      *    Convert to..... PIC S9(5) USAGE IS DISPLAY
      *    The resulting field will still be implied decimal. The field
      *    length will be 6-bytes, a single (1-byte) leading sign
      *    and five (5-bytes) digits.
      *
           perform CONVERT-TO-DISPLAY

      *    ------------------------------------------------------------
      *    Example-05, Show how to convert a packed number
      *    with two decimal position and an implied decimal point to a
      *    text string with a separate leading sign character and an
      *    explicit decimal point.
      *    Convert from... PIC S9(5) USAGE IS COMPUTATIONAL-3
      *    Convert to..... PIC X(7)
      *    The resulting field will have an explicit decimal point.
      *    The field length will be 7-bytes, a single (1-byte) leading
      *    sign, three (3-bytes) digits to the left of the decimal, a
      *    single (1-byte) decimal point and two (2-bytes) digits to
      *    the right of the decimal point.
      *
           perform CONVERT-TO-DISPLAY-PIC-X

      *    ------------------------------------------------------------
      *    Example-06, Show how to convert a packed number
      *    with two decimal position and an implied decimal point to a
      *    text string with a separate leading sign character and an
      *    explicit decimal point.
      *    Convert from... PIC S9(3)V99 USAGE IS COMPUTATIONAL-3
      *    Convert to..... PIC +ZZZ.99
      *    The resulting field will have an explicit decimal point.
      *    The field length will be 7-bytes, a single (1-byte) leading
      *    sign, three (3-bytes) digits to the left of the decimal, a
      *    single (1-byte) decimal point and two (2-bytes) digits to
      *    the right of the decimal point.
      *
           perform CONVERT-TO-DISPLAY-PIC-Z

           GOBACK.

      *****************************************************************
       DUMP-ASTERISK-ROW.
           move 'NOTE' to SIMODUMP-REQUEST
           move all '*' to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           exit.

      *****************************************************************
       DUMP-ASTERISK-ROW-2X.
           perform DUMP-ASTERISK-SINGLE
           perform DUMP-ASTERISK-ROW
           exit.

      *****************************************************************
       DUMP-ASTERISK-SINGLE.
           move 'NOTE' to SIMODUMP-REQUEST
           move SPACES to SIMODUMP-BUFFER
           move '*'    to SIMODUMP-BUFFER(1:1)
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           exit.

      *****************************************************************
      * Descirbe the format for a zoned-decimal field...
      *****************************************************************
       ZONED-FIELD.
      *    Prepare to show the Number...
           move 'ZONED...' to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'Zoned-Decimal, Unsign, USAGE IS DISPLAY'
             to SIMODUMP-BUFFER
           move 'NOTE'         to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the field...
           add length of TEXT-ZONED-DECIMAL
               to ZERO giving SIMODUMP-LENGTH
           move SPACES         to SIMODUMP-BUFFER
           move TEXT-ZONED-DECIMAL to SIMODUMP-BUFFER
           move 'DUMP'         to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           move 'Zoned-Decimal, Signed, Positive, USAGE IS DISPLAY'
             to SIMODUMP-BUFFER
           move 'NOTE' to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the positive value...
           move SPACES         to SIMODUMP-BUFFER
           move TEXT-ZONED-DECIMAL-SIGN to SIMODUMP-BUFFER
           add length of TEXT-ZONED-DECIMAL-SIGN
               to ZERO giving SIMODUMP-LENGTH
           move 'DUMP'         to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           move 'Zoned-Decimal, Signed, Negative, USAGE IS DISPLAY'
             to SIMODUMP-BUFFER
           move 'NOTE' to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           move SPACES         to SIMODUMP-BUFFER
           subtract SIGN-ZONED-DECIMAL from ZERO
             giving SIGN-ZONED-DECIMAL
           move TEXT-ZONED-DECIMAL-SIGN to SIMODUMP-BUFFER
           add length of TEXT-ZONED-DECIMAL-SIGN
               to ZERO giving SIMODUMP-LENGTH
           move 'DUMP'         to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           exit.

      *****************************************************************
      * How to convert to a display field from packed or binary...
      *****************************************************************
       CONVERT-TO-DISPLAY.
           move 'CONVERT1' to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'Convert from Packed to Display'
             to SIMODUMP-BUFFER
           move 'NOTE'         to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           move 'The PACKED-DECIMAL field to be converted'
             to SIMODUMP-BUFFER
           move 'NOTE'         to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           add length of TEXT-PACKED-DECIMAL-SIGN
               to ZERO giving SIMODUMP-LENGTH
           move SPACES         to SIMODUMP-BUFFER
           move TEXT-PACKED-DECIMAL-SIGN to SIMODUMP-BUFFER
           move 'DUMP'         to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           move 'The DISPLAY field created by the conversion routine'
             to SIMODUMP-BUFFER
           move 'NOTE'         to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

      *    Convert the PACKED-DECIMAL field to a ZONE-DECIMAL field
      *    with a separate, leading sign. This filed has zero decimal
      *    positions.
      *              Text    Hexadecimal      Length
      *    INPUT:     123-   x'00123D'             3
      *    OUTPUT: -00123    x'60F0F0F1F2F3'       6
      *    Show the hexadecimal content of the unsigned value...
      *
           add SIGN-PACKED-DECIMAL to ZERO giving SIGN-LEAD-SEPARATE
      *    The preceding statement is the only statement required to do
      *    the conversion from packed-decimal to zone-decimal.
      *    The additional code in this section is used to display the
      *    input and result field values in hexadecimal dump format.
      *
           add length of SIGN-LEAD-SEPARATE
               to ZERO giving SIMODUMP-LENGTH
           move SPACES         to SIMODUMP-BUFFER
           move TEXT-SIGN-LEAD-SEPARATE to SIMODUMP-BUFFER
           move 'DUMP'         to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           exit.

      *****************************************************************
      * How to convert to a display field from packed or binary...
      *****************************************************************
       CONVERT-TO-DISPLAY-PIC-X.
           move 'CONVERT2' to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'Convert from Packed to Text, Decimal Point Value'
             to SIMODUMP-BUFFER
           move 'NOTE'         to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the unsigned value...
           add PACK-DECIMAL-S3V2 to ZERO giving SLS-S3V2-NUMB

           move SLS-S3V2-TEXT(1:1) to W-SIGN
           move SLS-S3V2-TEXT(2:3) to W-SIGN-VALUE
           move SLS-S3V2-TEXT(5:2) to W-SIGN-DECIMAL

           add length of W-SIGN-06
               to ZERO giving SIMODUMP-LENGTH
           move SPACES         to SIMODUMP-BUFFER
           move W-SIGN-06      to SIMODUMP-BUFFER
           move 'DUMP'         to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           exit.

      *****************************************************************
      * How to convert to a display field from packed or binary...
      *****************************************************************
       CONVERT-TO-DISPLAY-PIC-Z.
           move 'CONVERT3' to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'Positive Packed to Edited Text with Decimal Point'
             to SIMODUMP-BUFFER
           move 'NOTE'         to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

      *    The following statement will place a value into the
      *    packed-decimal field. The actual value will be x'00123C'.
           add 1.23 to ZERO giving PACK-DECIMAL-S3V2

      *    The following statement will place the arithmetic value of
      *    the packed-decimal field into the edited print field. The
      *    actual value will be x'4E4040F14BF2F3'. This will result in
      *    converting the packed-decimal field but has leading spaces.
           move PACK-DECIMAL-S3V2 to PRINT-NUMBER
      *    The following statement will replace the leading spaces
      *    with zeroes. The resulting value will be x'4EF0F0F14BF2F3'.
           inspect PRINT-NUMBER replacing all SPACE by ZERO
      *    The preceding 2 statements are the only statements required
      *    to do the conversion from packed-decimal to zone-decimal.
      *    The additional code in this section is used to display the
      *    input and result field values in hexadecimal dump format.
      *
           add length of PRINT-LINE
               to ZERO giving SIMODUMP-LENGTH
           move SPACES      to SIMODUMP-BUFFER
           move PRINT-LINE  to SIMODUMP-BUFFER
           move 'DUMP'      to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           move 'Negative Packed to Edited Text with Decimal Point'
             to SIMODUMP-BUFFER
           move 'NOTE'         to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           add -4.56 to ZERO giving PACK-DECIMAL-S3V2
           move PACK-DECIMAL-S3V2 to PRINT-NUMBER
           inspect PRINT-NUMBER replacing all SPACE by ZERO
           move PRINT-LINE  to SIMODUMP-BUFFER
           move 'DUMP'      to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           exit.

      *****************************************************************
      * Descirbe the format for a packed-decimal field...
      *****************************************************************
       PACKED-FIELD.
      *    Prepare to show the Number...
           move 'PACKED..' to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'Packed-Decimal, Unsign, USAGE IS COMP-3'
             to SIMODUMP-BUFFER
           move 'NOTE'         to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the unsigned value...
           add length of TEXT-PACKED-DECIMAL
               to ZERO giving SIMODUMP-LENGTH
           move SPACES         to SIMODUMP-BUFFER
           move TEXT-PACKED-DECIMAL to SIMODUMP-BUFFER
           move 'DUMP'         to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           move 'Packed-Decimal, Signed, Positive, USAGE IS COMP-3'
             to SIMODUMP-BUFFER
           move 'NOTE' to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the positive value...
           move SPACES         to SIMODUMP-BUFFER
           move TEXT-PACKED-DECIMAL-SIGN to SIMODUMP-BUFFER
           add length of TEXT-PACKED-DECIMAL-SIGN
               to ZERO giving SIMODUMP-LENGTH
           move 'DUMP'         to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           move 'Packed-Decimal, Signed, Negative, USAGE IS COMP-3'
             to SIMODUMP-BUFFER
           move 'NOTE' to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           move SPACES         to SIMODUMP-BUFFER
           subtract SIGN-PACKED-DECIMAL from ZERO
             giving SIGN-PACKED-DECIMAL
           move TEXT-PACKED-DECIMAL-SIGN to SIMODUMP-BUFFER
           add length of TEXT-PACKED-DECIMAL-SIGN
               to ZERO giving SIMODUMP-LENGTH
           move 'DUMP'         to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           exit.

      *****************************************************************
      * Descirbe the format for a binary field...
      *****************************************************************
       BINARY-FIELD.
      *    Prepare to show the Number...
           move 'BINARY..' to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'Binary Format, No Sign, USAGE IS COMP'
             to SIMODUMP-BUFFER
           move 'NOTE' to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the field...
           add length of TEXT-BINARY
               to ZERO giving SIMODUMP-LENGTH
           move SPACES         to SIMODUMP-BUFFER
           move TEXT-BINARY to SIMODUMP-BUFFER
           move 'DUMP'         to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           move 'Binary Format, Positive, USAGE IS COMP'
             to SIMODUMP-BUFFER
           move 'NOTE' to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the positive value...
           move SPACES         to SIMODUMP-BUFFER
           move TEXT-BINARY-SIGN to SIMODUMP-BUFFER
           add length of TEXT-BINARY-SIGN
               to ZERO giving SIMODUMP-LENGTH
           move 'DUMP'         to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           move 'Binary Format, Negative, USAGE IS COMP'
             to SIMODUMP-BUFFER
           move 'NOTE' to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           move SPACES         to SIMODUMP-BUFFER
           subtract SIGN-BINARY from ZERO
             giving SIGN-BINARY
           move TEXT-BINARY-SIGN to SIMODUMP-BUFFER
           add length of TEXT-BINARY-SIGN
               to ZERO giving SIMODUMP-LENGTH
           move 'DUMP'         to SIMODUMP-REQUEST
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER

           exit.

      *****************************************************************
       FIRST-TIME-LOGIC.
           perform Z-POST-COPYRIGHT.
           move 'OUT2' to SIMODUMP-OUTPUT
           move 'HIDE' to SIMODUMP-COPYRIGHT
           exit.

      *****************************************************************
      * The following Z-Routines perform administrative tasks         *
      * for this program.                                             *
      *****************************************************************
       Z-POST-CONSOLE-MESSAGE.
           display MESSAGE-BUFFER upon console
           move SPACES to MESSAGE-TEXT
           exit.

      *****************************************************************
       Z-POST-COPYRIGHT.
           display SIM-TITLE     upon console
           display SIM-COPYRIGHT upon console
           exit.

      *****************************************************************
       Z-POST-NOTE-AND-CLEAR.
           move 'NOTE' to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           move SPACES to SIMODUMP-BUFFER
           exit.

      *****************************************************************
       Z-THANK-YOU.
           display SIM-THANKS-01 upon console
           display SIM-THANKS-02 upon console
           exit.
      *****************************************************************
      *      This example is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *****************************************************************
